@@ -1,7 +1,7 @@
 /* vim:set et sts=4: */
 /* input-pad - The input pad
- * Copyright (C) 2010-2011 Takao Fujiwara <takao.fujiwara1@gmail.com>
- * Copyright (C) 2010-2011 Red Hat, Inc.
+ * Copyright (C) 2010-2012 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2010-2012 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -70,6 +70,13 @@ void                input_pad_window_reorder_button_pressed
                                         (void          *window_data);
 InputPadWindowKbduiName *
                     input_pad_window_get_kbdui_name_list (void);
+int                 input_pad_window_get_kbdui_name_list_length (void);
+char *              input_pad_window_get_kbdui_name_get_name_with_index
+                                        (int            index);
+char *              input_pad_window_get_kbdui_name_get_description_with_index
+                                        (int            index);
+InputPadWindowType  input_pad_window_get_kbdui_name_get_type_with_index
+                                        (int            index);
 void                input_pad_window_set_kbdui_name
                                         (void          *window_data,
                                          const char    *name);
